/**
 * @packageDocumentation
 * @module String
 */
import { Observable, ObservableInput } from 'rxjs';
import { ArrayOrSet } from '../types/array-set';
/**
 * Returns an Observable that emits a string made from code points using String.fromCodePoint
 *
 * @remarks This operator will emit a single string for all input passed including arrays
 *
 * @category Create
 *
 * @param args Observable input, Promise, Array or argument list of code points
 *
 * @example
 * Return a string from code points arguments
 * ```ts
 * fromCodePoint(9731, 9733, 9842).subscribe();
 * ```
 * Output: `☃★♲`
 *
 * @example
 * Return a string from code points array
 * ```ts
 * fromCodePoint([9731, 9733, 9842]).subscribe();
 * ```
 * Output: `☃★♲`
 *
 * @example
 * Return a string from code points Observable
 * ```ts
 * fromCodePoint(of([9731, 9733, 9842]).subscribe();
 * ```
 * Output: `☃★♲`
 *
 * @returns Observable that emits a string
 */
export declare function fromCodePoint<A extends ObservableInput<ArrayOrSet<number> | number> | PromiseLike<ArrayOrSet<number> | number> | ArrayOrSet<number> | number>(...args: A[]): Observable<string>;
