/**
 * @packageDocumentation
 * @module String
 */
import { ObservableInput, OperatorFunction } from 'rxjs';
/**
 * Returns an Observable that emits a boolean where the source string contains with the passed search string using
 * String.includes
 *
 * @category Query
 *
 * @see The [[filterIncludes]] operator returns the string value
 *
 * @param search The string to check the source ends with
 *
 * @example
 * Return a boolean where the source string includes 'JS'
 * ```ts
 * from(['RxJS', 'Ninja', 'Tests']).pipe(includes('JS')).subscribe();
 * ```
 * Output: `true, false, false`
 *
 * @returns Observable that emits a boolean
 */
export declare function includes(search: string | ObservableInput<string>): OperatorFunction<string, boolean>;
