/**
 * @packageDocumentation
 * @module String
 */
import { MonoTypeOperatorFunction, Observable } from 'rxjs';
import { ArrayOrSet } from '../types/array-set';
/**
 * Returns an Observable that emits a string where the source string is passed through String.toLocaleLowerCase
 *
 * @category Modify
 *
 * @param locales Optional locales to pass for string formatting
 *
 * @example
 * Returns an upper case string
 * ```ts
 * of('apple').pipe(toUpperCase()).subscribe();
 * ```
 * Output: `'APPLE'`
 *
 * @example
 * Returns an lower case string with locale
 * ```ts
 * of('äpfel').pipe(toUpperCase('de-DE')).subscribe();
 * ```
 * Output: `'ÄPFEL'`
 *
 * @returns Observable that emits a lower case string
 */
export declare function toUpperCase(locales?: ArrayOrSet<string> | string | Observable<ArrayOrSet<string> | string>): MonoTypeOperatorFunction<string>;
